package com.example.remotetest;

import java.util.Calendar;

public class MainUtils
{
	
	public static short[] convertNumberToDays(int number)
	{
		int len = 7;
		
		StringBuilder data = new StringBuilder(Integer.toBinaryString(number));
		for(int i = data.length();i<len;i++)
			data.insert(0, 0);
			
		char[] c = data.toString().toCharArray();
		
		short[] result = new short[len];
		for(int i = 0;i<len;i++)
			result[len - i - 1] = (short) (c[i] - 48); //48 = 0
		return result;
		
	}
	
	public static int convertDaysToNumber(short[] days)
	{
		int result = 0;
		if(days != null)
		{
			int len = (days.length < 7) ? days.length : 7;
			
			for(int i = 0;i<len;i++)
			{
				if(days[i] == 1)
					result += Math.pow(2, i);
			}
		}
		return result;
	}
	
	/**
	 * Convert seconds to time, min 0 = 0:0:0, max 86399 = 23:59:59
	 * But, seconds are ignored => time is rounded to minutes!
	 * Output format HH:mm => 22:59 
	 * @param time
	 * @return
	 */
	public static String convertNumberToTime(int time)
	{
		if(time >= 86400 || time < 0)
			throw new IllegalArgumentException(String.valueOf(time));
		int hours = 0;
		int minutes = 0;
		@SuppressWarnings("unused")
		int seconds = 0;
		while(time >= 3600)
		{
			hours++;
			time -= 3600;
		}
		
		while(time >= 60)
		{
			minutes++;
			time -= 60;
		}
		
		seconds = time;
		
		String mins = (minutes < 10) ? "0" + minutes : String.valueOf(minutes);
		//seconds are ignored now!
		return String.format("%s:%s",hours, mins);
	}
	
	/**
	 * Convert seconds to time, min 0 = 0:0:0, max 86399 = 23:59:59
	 * But, seconds are ignored => time is rounded to minutes!
	 * Output format HH:mm => 22:59 
	 * @param time
	 * @return
	 */
	public static String convertNumberToFormattedTime(int time, int timeFormat)
	{
		Calendar c = Calendar.getInstance();
		c.set(Calendar.HOUR_OF_DAY, 0);
		c.set(Calendar.MINUTE, 0);
		c.set(Calendar.SECOND,0);
		c.add(Calendar.SECOND, time);
		
		String result = null;
		if(timeFormat == 24)
			result = String.format("%s:%s",c.get(Calendar.HOUR_OF_DAY), getTwoDecimalNumber(c.get(Calendar.MINUTE)));
		else
		{
			int hours = c.get(Calendar.HOUR);
			boolean pm = c.get(Calendar.AM_PM) == Calendar.PM;
			if(hours == 0)
				hours = 12;									
			
			result = String.format("%s:%s %s",hours, getTwoDecimalNumber(c.get(Calendar.MINUTE)), pm ? "PM" : "AM");
		}
		return result;
		
	}
	
	/**
	 * Convert seconds to time, min 0 = 0:0:0, max 86399 = 23:59:59	 * 
	 * @param time
	 * @param outValues initialized  array of int of size 2, or 3. if 3, the last value is seconds!	 * 
	 */
	public static void convertNumberToTime(int time, int[] outValues)
	{
		if(time >= 86400 || time < 0)
			throw new IllegalArgumentException(String.valueOf(time));
		int hours = 0;
		int minutes = 0;
		int seconds = 0;
		while(time >= 3600)
		{
			hours++;
			time -= 3600;
		}
		
		while(time >= 60)
		{
			minutes++;
			time -= 60;
		}
		
		seconds = time;
		
		outValues[0] = hours;
		outValues[1] = minutes;
		if(outValues.length > 2)
			outValues[2] = seconds;
	}
	
	/**
	 * Convert day time to numbers, supported format only 24h! 
	 * @param time
	 * @return
	 */
	
	public static int convertTimeToNumber(String time)
	{
		String[] times = time.split(":");
		int hours = Integer.parseInt(times[0]);
		int minutes = Integer.parseInt(times[1]);
		
		if(hours > 23 || hours < 0 || minutes < 0 || minutes > 59)
			throw new IllegalArgumentException(time);
		
		return hours * 3600 + minutes * 60;
	}
	
	/**
	 * Convert day time to numbers, supported format only 12h! 
	 * @param time
	 * @return
	 */
	
	public static int convertTime12ToNumber(String time)
	{
		String[] parts = time.split(" ");
		String[] times = parts[0].split(":");
		int hours = Integer.parseInt(times[0]);
		int minutes = Integer.parseInt(times[1]);
		if(parts[1].trim().equalsIgnoreCase("pm") && hours < 12)
			hours += 12;
		
		if(hours > 23 || hours < 0 || minutes < 0 || minutes > 59)
			throw new IllegalArgumentException(time);
		
		return hours * 3600 + minutes * 60;
	}
	
	private static String getTwoDecimalNumber(String digit)
	{
		if(digit.length() == 1)
			return "0" + digit;
		else
			return digit;
	}
	
	public static String getTwoDecimalNumber(int digit)
	{
		return getTwoDecimalNumber(String.valueOf(digit));
	}
}
